'###################################################################
'ImportCsvData02.tcm macro for TurboCAD Pro v7 and v8
'Thomas Snape June 03, 2002  http://throsn.tripod.com
'This macro demonstrated a method to read 2D coordinate
'data from a file in CSV format, and uses the data to
'draw a graphic in the active drawing.
'###################################################################
Option Explicit

Sub ImportData()
Dim sFname As String 'path to file containing coordinate data
Dim sCoords() As String 'array to store coordinate data strings
Dim n As Integer 'counter used when resizing sCoords array

'STEP 1: GET PATH TO DATA FILE
'Uses API call in modGetOpenFileName
If GetOpenFname(sFname) Then
    MsgBox "File to be opened:" & vbCrLf & sFname
Else
    MsgBox "Dialog was cancelled"
    Exit Sub
End If

'STEP 2: OPEN DATA FILE FOR INPUT
'Read CSV data line by line
'and save in array variable
On Error GoTo Errhandler01
Open sFname For Input As #1
n = 1
Do While Not EOF(1)
    ReDim Preserve sCoords(n)
    Line Input #1, sCoords(n)
    n = n + 1
Loop
Close #1 'close file when finished reading coordinates

'STEP 3: PARSE COORDINATE VALUES FROM DATA
'STRINGS AND USE TO DRAW GRAPHIC IN DRAWING

Dim cFirst As Long 'variable to store postion of comma in strings
Dim x As Double 'the X coordinate for the vertex to be added
Dim y As Double 'the Y coordinate for the vertex to be added
Dim i As Integer 'index used while parsing
Dim j As Integer 'index used while parsing
Dim Gr As Graphic
Dim Dr As Drawing
Dim Grs As Graphics
On Error GoTo Errhandler02
Set Dr = Application.ActiveDrawing
Set Grs = Dr.Graphics
cFirst = 0
x = 0
y = 0
'following lines read strings in sCoords array
'and extract X and Y values
For i = 1 To UBound(sCoords)
     For j = 1 To Len(sCoords(i))
        If Mid(sCoords(i), j, 1) = "," Then
            cFirst = j
            Exit For
        Else
        End If
    Next j
    
    x = Val(Mid(sCoords(i), 1, cFirst - 1))
    y = Val(Mid(sCoords(i), cFirst + 1, Len(sCoords(i)) - cFirst + 1))
    
    If i = 1 Then 'first vertex, need to create new graphic
        Set Gr = Grs.AddCurveBezier(x, y, 0)
    Else 'graphic already exists, need to add more vertices
        Gr.Vertices.add x, y, 0
    End If
Next i
Dr.ActiveView.Refresh
Set Gr = Nothing
Set Grs = Nothing
Set Dr = Nothing
Exit Sub
Errhandler01:
    MsgBox "There was a problem reading the data file."
    Exit Sub
Errhandler02:
    MsgBox "There was a problem drawing the graphic with the supplied data." & vbCrLf & _
        "Check that the data is in the required CSV format."
    Set Gr = Nothing
    Set Grs = Nothing
    Set Dr = Nothing
    Exit Sub
End Sub
